==> openjdk-src-15.0.1.u9-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sat.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sat extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BR", "\u1c75\u1c68\u1c5f\u1c61\u1c64\u1c5e" },
            { "CN", "\u1c6a\u1c64\u1c71" },
            { "DE", "\u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71\u1c64" },
            { "FR", "\u1c6f\u1c77\u1c68\u1c5f\u1c71\u1c65" },
            { "GB", "\u1c6d\u1c69\u1c71\u1c64\u1c6d\u1c74\u1c6e\u1c70 \u1c60\u1c64\u1c5d\u1c70\u1c5a\u1c62" },
            { "IN", "\u1c64\u1c71\u1c70\u1c64\u1c6d\u1c5f" },
            { "IT", "\u1c64\u1c74\u1c5e\u1c64" },
            { "JP", "\u1c61\u1c5f\u1c6f\u1c5f\u1c71" },
            { "RU", "\u1c68\u1c69\u1c65" },
            { "US", "\u1c6d\u1c69\u1c71\u1c5f\u1c6d\u1c74\u1c6e\u1c70 \u1c6e\u1c65\u1c74\u1c6e\u1c74" },
            { "ZZ", "\u1c75\u1c5f\u1c5d\u1c69\u1c68\u1c69\u1c62 \u1c74\u1c5a\u1c74\u1c77\u1c5f" },
            { "de", "\u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71" },
            { "en", "\u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "es", "\u1c6e\u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "fr", "\u1c6f\u1c77\u1c68\u1c6e\u1c67\u1c6a" },
            { "it", "\u1c64\u1c74\u1c5f\u1c5e\u1c64\u1c5f\u1c71" },
            { "ja", "\u1c61\u1c5f\u1c6f\u1c5f\u1c71\u1c64" },
            { "pt", "\u1c6f\u1c69\u1c68\u1c5b\u1c5c\u1c5f\u1c5e\u1c64" },
            { "ru", "\u1c68\u1c69\u1c65\u1c64\u1c6d\u1c5f\u1c71" },
            { "zh", "\u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d" },
            { "sat", "\u1c65\u1c5f\u1c71\u1c5b\u1c5f\u1c72\u1c64" },
            { "und", "\u1c75\u1c5f\u1c5d \u1c69\u1c68\u1c69\u1c62 \u1c6f\u1c5f\u1c79\u1c68\u1c65\u1c64" },
            { "Arab", "\u1c5f\u1c68\u1c75\u1c64\u1c60" },
            { "Cyrl", "\u1c65\u1c64\u1c68\u1c64\u1c5e\u1c64\u1c60" },
            { "Deva", "\u1c6b\u1c6e\u1c63\u1c5f\u1c71\u1c5f\u1c5c\u1c5f\u1c68\u1c64" },
            { "Hans", "\u1c65\u1c64\u1c62\u1c6f\u1c5e\u1c64\u1c6f\u1c5f\u1c6d\u1c64\u1c70" },
            { "Hant", "\u1c74\u1c68\u1c6e\u1c70\u1c64\u1c65\u1c5a\u1c71" },
            { "Latn", "\u1c5e\u1c6e\u1c74\u1c64\u1c71" },
            { "Olck", "\u1c5a\u1c5e \u1c6a\u1c64\u1c60\u1c64" },
            { "Zxxx", "\u1c75\u1c5f\u1c5d \u1c5a\u1c5e \u1c5f\u1c60\u1c5f\u1c71" },
            { "Zzzz", "\u1c75\u1c5f\u1c5d \u1c69\u1c68\u1c69\u1c62 \u1c6a\u1c64\u1c60\u1c64" },
            { "de_AT", "\u1c5a\u1c65\u1c74\u1c68\u1c64\u1c6d\u1c5f \u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71" },
            { "de_CH", "\u1c65\u1c69\u1c63\u1c64\u1c65 \u1c66\u1c5f\u1c64 \u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71" },
            { "en_AU", "\u1c5a\u1c65\u1c74\u1c68\u1c6e\u1c5e\u1c64\u1c6d\u1c5f\u1c71 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "en_CA", "\u1c60\u1c5f\u1c71\u1c5f\u1c70\u1c64\u1c6d\u1c5f\u1c71 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "en_GB", "\u1c75\u1c68\u1c64\u1c74\u1c64\u1c65 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "en_US", "\u1c5f\u1c62\u1c6e\u1c68\u1c64\u1c60\u1c5f\u1c71 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "es_ES", "\u1c68\u1c69\u1c65\u1c64\u1c6d\u1c5f\u1c71 \u1c6e\u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "es_MX", "\u1c62\u1c6e\u1c60\u1c65\u1c64\u1c60\u1c5f\u1c71 \u1c6e\u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "fr_CA", "\u1c60\u1c5f\u1c71\u1c5f\u1c70\u1c64\u1c6d\u1c5f\u1c71 \u1c6f\u1c77\u1c68\u1c6e\u1c67\u1c6a" },
            { "fr_CH", "\u1c65\u1c69\u1c63\u1c64\u1c65 \u1c6f\u1c77\u1c68\u1c6e\u1c67\u1c6a" },
            { "pt_BR", "\u1c75\u1c68\u1c5f\u1c61\u1c64\u1c5e\u1c64\u1c6d\u1c5f\u1c71 \u1c6f\u1c69\u1c68\u1c5b\u1c5c\u1c5f\u1c5e\u1c64" },
            { "pt_PT", "\u1c6d\u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c6f\u1c69\u1c68\u1c5b\u1c5c\u1c5f\u1c5e\u1c64" },
            { "es_419", "\u1c5e\u1c6e\u1c74\u1c64\u1c71 \u1c5f\u1c62\u1c6e\u1c68\u1c64\u1c60\u1c5f\u1c71 \u1c6e\u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "zh_Hans", "\u1c5f\u1c5e\u1c5c\u1c5f\u1c63\u1c5f\u1c60\u1c5f\u1c71 \u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d" },
            { "zh_Hant", "\u1c74\u1c68\u1c6e\u1c70\u1c64\u1c65\u1c71\u1c5f\u1c5e \u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d" },
            { "type.nu.latn", "\u1c63\u1c6e\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c6e\u1c5e" },
            { "type.co.standard", "\u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5b\u1c77\u1c5f\u1c68 \u1c5f\u1c78\u1c6b\u1c6e" },
            { "type.ca.gregorian", "\u1c5c\u1c68\u1c6e\u1c5c\u1c5a\u1c68\u1c64\u1c6d\u1c5f\u1c71 \u1c60\u1c5f\u1c5e\u1c6e\u1c71\u1c70\u1c5f\u1c68" },
        };
        return data;
    }
}

==> openjdk-src-23.0.1.u0-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sat.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sat extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BR", "\u1c75\u1c68\u1c5f\u1c61\u1c64\u1c5e" },
            { "CN", "\u1c6a\u1c64\u1c71" },
            { "DE", "\u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71\u1c64" },
            { "FR", "\u1c6f\u1c77\u1c68\u1c5f\u1c71\u1c65" },
            { "GB", "\u1c6d\u1c69\u1c71\u1c64\u1c6d\u1c74\u1c6e\u1c70 \u1c60\u1c64\u1c5d\u1c70\u1c5a\u1c62" },
            { "IN", "\u1c64\u1c71\u1c70\u1c64\u1c6d\u1c5f" },
            { "IT", "\u1c64\u1c74\u1c5e\u1c64" },
            { "JP", "\u1c61\u1c5f\u1c6f\u1c5f\u1c71" },
            { "RU", "\u1c68\u1c69\u1c65" },
            { "US", "\u1c6d\u1c69\u1c71\u1c5f\u1c6d\u1c74\u1c6e\u1c70 \u1c6e\u1c65\u1c74\u1c6e\u1c74" },
            { "ZZ", "\u1c75\u1c5f\u1c5d\u1c69\u1c68\u1c69\u1c62 \u1c74\u1c5a\u1c74\u1c77\u1c5f" },
            { "ab", "\u1c5f\u1c79\u1c75\u1c60\u1c77\u1c5f\u1c61\u1c64\u1c6d\u1c5f\u1c79\u1c71" },
            { "af", "\u1c5f\u1c6f\u1c77\u1c68\u1c64\u1c60\u1c5f\u1c71\u1c65" },
            { "ak", "\u1c5f\u1c60\u1c5f\u1c71" },
            { "am", "\u1c5f\u1c62\u1c66\u1c5f\u1c68\u1c64\u1c60" },
            { "an", "\u1c5f\u1c68\u1c5f\u1c5c\u1c5a\u1c71\u1c64\u1c61\u1c7d" },
            { "ar", "\u1c5a\u1c68\u1c75\u1c64" },
            { "as", "\u1c5f\u1c65\u1c5f\u1c62\u1c64\u1c61\u1c7d" },
            { "de", "\u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71" },
            { "en", "\u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "es", "\u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "fr", "\u1c6f\u1c77\u1c68\u1c6e\u1c67\u1c6a" },
            { "hy", "\u1c5f\u1c68\u1c62\u1c6e\u1c71\u1c64\u1c6d\u1c5f\u1c79\u1c71" },
            { "it", "\u1c64\u1c74\u1c5f\u1c5e\u1c64\u1c5f\u1c71" },
            { "ja", "\u1c61\u1c5f\u1c6f\u1c5f\u1c71\u1c64" },
            { "pt", "\u1c6f\u1c69\u1c68\u1c5b\u1c5c\u1c5f\u1c5e\u1c64" },
            { "ru", "\u1c68\u1c69\u1c65\u1c64\u1c6d\u1c5f\u1c71" },
            { "sq", "\u1c5f\u1c5e\u1c75\u1c5f\u1c71\u1c64\u1c6d\u1c5f\u1c79\u1c71" },
            { "zh", "\u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d" },
            { "ace", "\u1c5f\u1c60\u1c77\u1c64\u1c71\u1c64\u1c61\u1c7d" },
            { "ada", "\u1c5f\u1c79\u1c70\u1c5f\u1c71\u1c5c\u1c7d\u1c62\u1c6e" },
            { "ady", "\u1c5f\u1c79\u1c70\u1c6d\u1c5c\u1c77\u1c6e" },
            { "agq", "\u1c5f\u1c5c\u1c77\u1c6e\u1c62" },
            { "ain", "\u1c5f\u1c6d\u1c64\u1c71\u1c69" },
            { "ale", "\u1c5f\u1c5e\u1c6e\u1c63\u1c74" },
            { "anp", "\u1c5f\u1c79\u1c5d\u1c5c\u1c64\u1c60\u1c5f" },
            { "arp", "\u1c5f\u1c68\u1c5f\u1c6f\u1c5f\u1c66\u1c5a" },
            { "rup", "\u1c5f\u1c68\u1c5a\u1c62\u1c5f\u1c71\u1c64\u1c6d\u1c5f\u1c79\u1c71" },
            { "sat", "\u1c65\u1c5f\u1c71\u1c5b\u1c5f\u1c72\u1c64" },
            { "und", "\u1c75\u1c5f\u1c5d \u1c69\u1c68\u1c69\u1c62 \u1c6f\u1c5f\u1c79\u1c68\u1c65\u1c64" },
            { "Arab", "\u1c5f\u1c68\u1c75\u1c64\u1c60" },
            { "Cyrl", "\u1c65\u1c64\u1c68\u1c64\u1c5e\u1c64\u1c60" },
            { "Deva", "\u1c6b\u1c6e\u1c63\u1c5f\u1c71\u1c5f\u1c5c\u1c5f\u1c68\u1c64" },
            { "Hans", "\u1c65\u1c64\u1c62\u1c6f\u1c5e\u1c64\u1c6f\u1c5f\u1c6d\u1c64\u1c70" },
            { "Hant", "\u1c74\u1c68\u1c6e\u1c70\u1c64\u1c65\u1c5a\u1c71\u1c5f\u1c5e" },
            { "Latn", "\u1c5e\u1c6e\u1c74\u1c64\u1c71" },
            { "Olck", "\u1c5a\u1c5e \u1c6a\u1c64\u1c60\u1c64" },
            { "Zxxx", "\u1c75\u1c5f\u1c5d \u1c5a\u1c5e \u1c5f\u1c60\u1c5f\u1c71" },
            { "Zzzz", "\u1c75\u1c5f\u1c5d \u1c69\u1c68\u1c69\u1c62 \u1c6a\u1c64\u1c60\u1c64" },
            { "de_AT", "\u1c5a\u1c65\u1c74\u1c68\u1c64\u1c6d\u1c5f \u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71" },
            { "de_CH", "\u1c65\u1c69\u1c63\u1c64\u1c65 \u1c66\u1c5f\u1c64 \u1c61\u1c5f\u1c68\u1c62\u1c5f\u1c71" },
            { "en_AU", "\u1c5a\u1c65\u1c74\u1c68\u1c6e\u1c5e\u1c64\u1c6d\u1c5f\u1c71 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "en_CA", "\u1c60\u1c5f\u1c71\u1c5f\u1c70\u1c64\u1c6d\u1c5f\u1c71 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "en_GB", "\u1c75\u1c68\u1c64\u1c74\u1c64\u1c65 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "en_US", "\u1c5f\u1c62\u1c6e\u1c68\u1c64\u1c60\u1c5f\u1c71 \u1c5f\u1c5d\u1c5c\u1c7d\u1c68\u1c6e\u1c61\u1c64" },
            { "es_ES", "\u1c68\u1c69\u1c65\u1c64\u1c6d\u1c5f\u1c71 \u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "es_MX", "\u1c62\u1c6e\u1c60\u1c65\u1c64\u1c60\u1c5f\u1c71 \u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "fr_CA", "\u1c60\u1c5f\u1c71\u1c5f\u1c70\u1c64\u1c6d\u1c5f\u1c71 \u1c6f\u1c77\u1c68\u1c6e\u1c67\u1c6a" },
            { "fr_CH", "\u1c65\u1c69\u1c63\u1c64\u1c65 \u1c6f\u1c77\u1c68\u1c6e\u1c67\u1c6a" },
            { "pt_BR", "\u1c75\u1c68\u1c5f\u1c61\u1c64\u1c5e\u1c64\u1c6d\u1c5f\u1c71 \u1c6f\u1c69\u1c68\u1c5b\u1c5c\u1c5f\u1c5e\u1c64" },
            { "pt_PT", "\u1c6d\u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c6f\u1c69\u1c68\u1c5b\u1c5c\u1c5f\u1c5e\u1c64" },
            { "ar_001", "\u1c5f\u1c6b\u1c77\u1c69\u1c71\u1c64\u1c60 \u1c62\u1c5f\u1c71\u1c5a\u1c60 \u1c5a\u1c68\u1c75\u1c64" },
            { "es_419", "\u1c5e\u1c6e\u1c74\u1c64\u1c71 \u1c5f\u1c62\u1c6e\u1c68\u1c64\u1c60\u1c5f\u1c71 \u1c65\u1c6f\u1c6e\u1c71\u1c64\u1c65" },
            { "zh_Hans", "\u1c5f\u1c5e\u1c5c\u1c5f\u1c63\u1c5f\u1c60\u1c5f\u1c71 \u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d" },
            { "zh_Hant", "\u1c74\u1c68\u1c6e\u1c70\u1c64\u1c65\u1c71\u1c5f\u1c5e \u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d" },
            { "type.nu.latn", "\u1c63\u1c6e\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c6e\u1c5e" },
            { "type.nu.hanidec", "\u1c6a\u1c5f\u1c6d\u1c71\u1c64\u1c61\u1c7d \u1c70\u1c6e\u1c65\u1c64\u1c62\u1c5f\u1c79\u1c5e \u1c6e\u1c5e\u1c60\u1c77\u1c5f" },
            { "type.nu.hansfin", "\u1c65\u1c5a\u1c66\u1c5a\u1c61\u1c7d \u1c6a\u1c64\u1c71 \u1c6f\u1c77\u1c5f\u1c6d\u1c71\u1c6e\u1c71\u1c65\u1c64\u1c5f\u1c79\u1c5e \u1c6e\u1c5e\u1c60\u1c77\u1c5f" },
            { "type.nu.jpanfin", "\u1c61\u1c5f\u1c6f\u1c5f\u1c71\u1c64\u1c61\u1c7d \u1c6f\u1c77\u1c5f\u1c6d\u1c71\u1c6e\u1c71\u1c65\u1c64\u1c5f\u1c79\u1c5e \u1c6e\u1c5e\u1c60\u1c77\u1c5f" },
            { "type.co.standard", "\u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5b\u1c77\u1c5f\u1c68 \u1c5f\u1c78\u1c6b\u1c6e" },
            { "type.ca.gregorian", "\u1c5c\u1c68\u1c6e\u1c5c\u1c5a\u1c68\u1c64\u1c6d\u1c5f\u1c71 \u1c60\u1c5f\u1c5e\u1c6e\u1c71\u1c70\u1c5f\u1c68" },
        };
        return data;
    }
}
